@@ -20,25 +20,25 @@ void LDAcov::iteration_single(int it)
   // Create Alpha for this iteration
   Alpha = (C * Lambda.transpose()).array().exp();
 
-  for (int ii = 0; ii < num_doc; ii++) {
+  for (int ii = 0; ii < num_doc; ++ii) {
     doc_id_ = doc_indexes[ii];
     doc_z = Z[doc_id_], doc_w = W[doc_id_];
     doc_length = doc_each_len[doc_id_];
-    
+
     token_indexes = sampler::shuffled_indexes(doc_length); //shuffle
-    
+
     // Prepare Alpha for the doc
     alpha = Alpha.row(doc_id_).transpose(); // take out alpha
-    
+
     // Iterate each word in the document
-    for (int jj = 0; jj < doc_length; jj++) {
+    for (int jj = 0; jj < doc_length; ++jj) {
       w_position = token_indexes[jj];
       z_ = doc_z[w_position], w_ = doc_w[w_position];
-    
+
       new_z = sample_z(alpha, z_, s_, w_, doc_id_);
       doc_z[w_position] = new_z;
     }
-    
+
     Z[doc_id_] = doc_z;
   }
   sample_parameters(it);
@@ -48,8 +48,8 @@ void LDAcov::iteration_single(int it)
 double LDAcov::loglik_total()
 {
   double loglik = 0.0;
-  for (int k = 0; k < num_topics; k++) {
-    for (int v = 0; v < num_vocab; v++) { // word
+  for (int k = 0; k < num_topics; ++k) {
+    for (int v = 0; v < num_vocab; ++v) { // word
       loglik += mylgamma(beta + n_kv(k, v)) - mylgamma(beta);
     }
 
@@ -63,19 +63,19 @@ double LDAcov::loglik_total()
   Alpha = (C * Lambda.transpose()).array().exp();
   alpha = VectorXd::Zero(num_topics);
 
-  for (int d = 0; d < num_doc; d++) {
-    alpha = Alpha.row(d).transpose(); // Doc alpha, column vector  
-    
+  for (int d = 0; d < num_doc; ++d) {
+    alpha = Alpha.row(d).transpose(); // Doc alpha, column vector
+
     loglik += mylgamma( alpha.sum() ) - mylgamma( doc_each_len_weighted[d] + alpha.sum() );
-    for (int k = 0; k < num_topics; k++) {
+    for (int k = 0; k < num_topics; ++k) {
       loglik += mylgamma( n_dk(d,k) + alpha(k) ) - mylgamma( alpha(k) );
     }
   }
 
   // Lambda loglik
   double prior_fixedterm = -0.5 * log(2.0 * PI_V * std::pow(sigma, 2.0) );
-  for (int k = 0; k < num_topics; k++) {
-    for (int t = 0; t < num_cov; t++) {
+  for (int k = 0; k < num_topics; ++k) {
+    for (int t = 0; t < num_cov; ++t) {
       loglik += prior_fixedterm;
       loglik -= ( std::pow( (Lambda(k,t) - mu) , 2.0) / (2.0 * std::pow(sigma, 2.0)) );
     }
