@@ -83,6 +83,11 @@ void keyATMmeta::read_data_common()
   prior_gamma = Rcpp::as<Eigen::MatrixXd>(RMatrix);
   beta_s = priors_list["beta_s"];
 
+  eta_1 = priors_list["eta_1"];
+  eta_2 = priors_list["eta_2"];
+  eta_1_regular = priors_list["eta_1_regular"];
+  eta_2_regular = priors_list["eta_2_regular"];
+
   // Stored values
   stored_values = model["stored_values"];
 
@@ -108,11 +113,7 @@ void keyATMmeta::initialize()
 
 void keyATMmeta::initialize_common()
 {
-  // Parameters
-  eta_1 = 1.0;
-  eta_2 = 1.0;
-  eta_1_regular = 2.0;
-  eta_2_regular = 1.0;
+  // Prior values are set in `keyATMmeta::read_data_common()`
 
   // Slice sampling initialization for alpha
   // this is used except cov models
